/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.isobus.model;

import org.openide.util.NbPreferences;

/**
 *
 * @author Timon Veenstra
 */
public enum IsobusPreference {

    LOAD_DIR("loadDir", ""),
    ARCHIVE("archive", ""),
    LAST_DIR("lastDir", System.getProperty("user.dir")),
    LAST_EXPORT_DIR("lastDir", System.getProperty("user.dir"))
    ;

    private String propertyName;
    private String defaultProperty;

    private IsobusPreference(String propertyName, String defaultProperty) {
        this.propertyName = propertyName;
        this.defaultProperty = defaultProperty;
    }

    public String getDefaultProperty() {
        return defaultProperty;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public String getValue() {
        return NbPreferences.forModule(this.getClass()).get(this.getPropertyName(), this.getDefaultProperty());
    }

    public void saveValue(String value) {
        NbPreferences.forModule(this.getClass()).put(this.getPropertyName(), value);
    }
}
